@@ -251,8 +251,12 @@ ensure_unused_cb (UDisksClient *client, GAsyncResult *res, CreateFormatData *dat
     }
 
   if (get_encrypt (data))
-    g_variant_builder_add (&options_builder, "{sv}", "encrypt.passphrase",
-                           g_variant_new_string (gdu_create_password_page_get_password (data->password_page)));
+    {
+      g_variant_builder_add (&options_builder, "{sv}", "encrypt.passphrase",
+                             g_variant_new_string (gdu_create_password_page_get_password (data->password_page)));
+
+      g_variant_builder_add (&options_builder, "{sv}", "encrypt.type", g_variant_new_string ("luks2"));
+    }
 
   if (erase_type != NULL)
     g_variant_builder_add (&options_builder, "{sv}", "erase", g_variant_new_string (erase_type));
@@ -412,7 +416,6 @@ void
 gdu_create_format_show (UDisksClient *client,
                         GtkWindow    *parent_window,
                         UDisksObject *object,
-                        gboolean      show_custom,  /* e.g. hide custom format page from nautilus */
                         gboolean      add_partition, /* format vs add partition and format */
                         guint64       add_partition_offset,
                         guint64       add_partition_maxsize,
@@ -456,7 +459,7 @@ gdu_create_format_show (UDisksClient *client,
       data->partition_page = NULL;
     }
 
-  data->filesystem_page = gdu_create_filesystem_page_new (data->client, show_custom, data->drive);
+  data->filesystem_page = gdu_create_filesystem_page_new (data->client, data->drive);
   gtk_stack_add_titled (data->stack, GTK_WIDGET (data->filesystem_page), FORMAT_PAGE, _("Format Volume"));
   g_signal_connect (data->filesystem_page, "notify::complete", G_CALLBACK (update_dialog), data);
   data->other_page = gdu_create_other_page_new (data->client);
